/*	aisa54.h

	AISA-P54W/H Win32 API.
*/

#ifndef	AISA54_H
#define	AISA54_H	0x7054

#ifdef	__cplusplus
extern	"C"
{
#endif

/* Errors */

#define	AISA54_SUCCESS				0	/* Successfully proccessed */
#define	AISA54_ERR_SYSTEM			1	/* Call GetLastError() */
#define	AISA54_ERR_NO_DEVICE		2	/* No card */
#define	AISA54_ERR_IN_USE			3	/* Device is in use */
#define	AISA54_ERR_INVALID_SLOT		4	/* Invalid logical slot */
#define	AISA54_ERR_RESOURCE			5	/* Resource exhaustion */
#define	AISA54_ERR_INVALID_PORT		6	/* Invalid port */
#define	AISA54_ERR_INVALID_ARGUMENT	7	/* Invalid argument */

/* Direction */

#define	AISA54_DIR_A_OUTPUT	(0 << 0)
#define	AISA54_DIR_A_INPUT	(1 << 0)
#define	AISA54_DIR_B_OUTPUT	(0 << 1)
#define	AISA54_DIR_B_INPUT	(1 << 1)
#define	AISA54_DIR_C_OUTPUT	(0 << 2)
#define	AISA54_DIR_C_INPUT	(1 << 2)
#define	AISA54_DIR_D_OUTPUT	(0 << 3)
#define	AISA54_DIR_D_INPUT	(1 << 3)
#define	AISA54_DIR_E_OUTPUT	(0 << 4)
#define	AISA54_DIR_E_INPUT	(1 << 4)
#define	AISA54_DIR_F_OUTPUT	(0 << 5)
#define	AISA54_DIR_F_INPUT	(1 << 5)

/* Port numbers */

#define	AISA54_PORT_A	0
#define	AISA54_PORT_B	1
#define	AISA54_PORT_C	2
#define	AISA54_PORT_D	3
#define	AISA54_PORT_E	4
#define	AISA54_PORT_F	5

/* Miscsellaneous */

#define	AISA54_MAX_SLOTS	16			/* Maximum number of slots */

#define	AISA54_SLOT_AUTO	((WORD) ~0U)

/* Device ID */

#define	AISA54_DEVICE_ID	(0x54UL | ('P' << 8) | (0x0000UL << 16))

/* Resource infomation structure */

#define	AISA54_MAX_MEM		9
#define	AISA54_MAX_IO		20
#define	AISA54_MAX_IRQ		7
#define	AISA54_MAX_DMA		7

typedef	struct	_AISA54RESOURCE
{
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[AISA54_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[AISA54_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[AISA54_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[AISA54_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[AISA54_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Num IRQ info */
	DWORD	dwIRQRegisters	[AISA54_MAX_IRQ];	/* IRQ list */
	DWORD	dwIRQAttrib		[AISA54_MAX_IRQ];	/* IRQ Attrib list */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[AISA54_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[AISA54_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
}	AISA54RESOURCE;

typedef	AISA54RESOURCE		*	PAISA54R;
typedef	AISA54RESOURCE	FAR	*	LPAISA54R;

#ifndef	AISA54_API
#define	AISA54_API	1

#ifndef	AISA54_DS
#define	AISA54_DS	__declspec(dllimport)
#endif

AISA54_DS
BOOL	WINAPI Aisa54GetVersion(LPDWORD lpdwDllVersion, LPDWORD lpdwVxdVersion);
AISA54_DS
BOOL	WINAPI Aisa54Create(LPWORD lpwLogSlot );
AISA54_DS
BOOL	WINAPI Aisa54Close(WORD wLogSlot);
AISA54_DS
BOOL	WINAPI Aisa54GetNumPorts(WORD wLogSlot, LPDWORD lpdwNumPorts);
AISA54_DS
BOOL	WINAPI Aisa54GetResource(WORD wLogSlot, LPAISA54R lpres);
AISA54_DS
BOOL	WINAPI Aisa54GetDirections(WORD wLogSlot, LPDWORD lpdwDirections);
AISA54_DS
BOOL	WINAPI Aisa54SetDirections(WORD wLogSlot, DWORD dwDirections);
AISA54_DS
BOOL	WINAPI Aisa54InPort(WORD wLogSlot, DWORD dwLogPort, LPBYTE lpbInValue);
AISA54_DS
BOOL	WINAPI Aisa54OutPort(WORD wLogSlot, DWORD dwPort, BYTE bOutValue);
AISA54_DS
DWORD	WINAPI Aisa54GetLastError(WORD wLogSlot);

#endif	/* #ifndef	AISA54_API */

#ifdef	__cplusplus
}
#endif

#endif	/* #ifndef	AISA54_H */
